@@ -12,6 +12,14 @@ import urwid
 from lookatme.exceptions import IgnoredByContrib
 
 
+def user_warnings():
+    """No warnings exist for this extension. Anything you want to warn the
+    user about, such as security risks in processing untrusted markdown, should
+    go here.
+    """
+    return []
+
+
 def render_code(token, body, stack, loop):
     lang = token["lang"] or ""
     if lang != "calendar":
